@@ -8,10 +8,6 @@ module Mocha
       stubbee
     end
 
-    def method_body(method)
-      PRE_RUBY_V19 ? proc { |*args, &block| method.call(*args, &block) } : method
-    end
-
     def stubbee_method(method_name)
       stubbee._method(method_name)
     end
